@@ -154,9 +154,8 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.25';
+our $VERSION = '0.2501';
 
-## no critic qw(ProhibitConstantPragma RequireArgUnpacking RequireCarping RequireCheckingReturnValueOfEval RequireInitializationForLocalVars)
 
 # Safe operations on symbol stash
 BEGIN {
@@ -1117,7 +1116,6 @@ sub catch {
     }
     else {
         # Recover exception from $@ and clear it
-        ## no critic qw(RequireLocalizedPunctuationVars)
         $e = $@;
         $@ = '';
     };
@@ -1227,7 +1225,7 @@ Matches against the default attribute, usually the C<message> attribute.
 =cut
 
 # Smart matching.
-sub matches {   ## no critic qw(ProhibitExcessComplexity)
+sub matches {
     my ($self, $that) = @_;
 
     my @args;
@@ -1320,7 +1318,6 @@ sub matches {   ## no critic qw(ProhibitExcessComplexity)
             $key = $default_attribute;
         };
 
-        ## no critic qw(ProhibitCascadingIfElse)
         if ($key eq '-isa') {
             if (ref $val eq 'ARRAY') {
                 my $arrret = 0;
@@ -1362,7 +1359,7 @@ sub matches {   ## no critic qw(ProhibitExcessComplexity)
                     local $_ = ref $self->{$key} eq 'ARRAY'
                                ? sprintf(
                                      @{$self->{$key}}[0],
-                                     @{$self->{$key}}[1..@{$self->{$key}}]
+                                     @{$self->{$key}}[1..$#{$self->{$key}}]
                                  )
                                : $self->{$key};
                     if (ref $arrval eq 'CODE') {
@@ -1393,7 +1390,7 @@ sub matches {   ## no critic qw(ProhibitExcessComplexity)
             local $_ = ref $self->{$key} eq 'ARRAY'
                        ? sprintf(
                              @{$self->{$key}}[0],
-                             @{$self->{$key}}[1..@{$self->{$key}}]
+                             @{$self->{$key}}[1..$#{$self->{$key}}]
                          )
                        : $self->{$key};
 
@@ -1613,7 +1610,7 @@ sub _string_attributes {
     my ($self) = @_;
 
     return map { ref $_ eq 'ARRAY'
-                 ? sprintf(@$_[0], @$_[1..@$_])
+                 ? sprintf(@$_[0], @$_[1..$#$_])
                  : $_ }
            grep { defined $_ and (ref $_ or $_ ne '') }
            map { $self->{$_} }
@@ -1664,7 +1661,6 @@ sub _collect_system_data {
         my @caller_stack;
         my $level = 1;
 
-        ## no critic qw(ProhibitMultiplePackages ProhibitPackageVars)
         while (my @c = do { package DB; caller($level++) }) {
             # Skip own package
             next if ! defined $Isa_Package{$c[0]} ? $Isa_Package{$c[0]} = do { local $@; local $SIG{__DIE__}; eval { $c[0]->isa(__PACKAGE__) } } : $Isa_Package{$c[0]};
@@ -1799,7 +1795,6 @@ sub _format_arg {
 
     $arg = "\"$arg\"" unless $arg =~ /^-?[\d.]+\z/;
 
-    ## no critic qw(ProhibitNoWarnings)
     no warnings 'once', 'utf8';   # can't disable critic for utf8...
     if (not defined *utf8::is_utf{CODE} or utf8::is_utf8($arg)) {
         $arg = join('', map { $_ > 255
@@ -1822,7 +1817,6 @@ sub _str_len_trim {
     my (undef, $str, $max) = @_;
     $max = 0 unless defined $max;
     if ($max > 2 and $max < length($str)) {
-        ## no critic qw(ProhibitLvalueSubstr)
         substr($str, $max - 3) = '...';
     };
 
@@ -2101,7 +2095,6 @@ sub _make_exception {
     };
 
     # Create the new package
-    ## no critic qw(ProhibitCommaSeparatedStatements)
     *{_qualify_to_ref("${package}::VERSION")} = \$version;
     *{_qualify_to_ref("${package}::ISA")} = [ $isa ];
     *{_qualify_to_ref("${package}::ATTRS")} = sub () {
@@ -2114,7 +2107,6 @@ sub _make_exception {
 
 
 # Module initialization
-## no critic qw(ProtectPrivateSubs)
 BEGIN {
     __PACKAGE__->_make_accessors;
     __PACKAGE__->_make_caller_info_accessors;
@@ -2124,54 +2116,56 @@ BEGIN {
 1;
 
 
-=begin umlwiki
+=begin plantuml
 
-= Class Diagram =
+class Exception::Base <<exception>> {
+  +ignore_class : ArrayRef = []
+  +ignore_level : Int = 0
+  +ignore_package : ArrayRef = []
+  +max_arg_len : Int = 64
+  +max_arg_nums : Int = 8
+  +max_eval_len : Int = 0
+  +message : Str|ArrayRef[Str] = "Unknown exception"
+  +value : Int = 0
+  +verbosity : Int = 2
+  ..
+  +caller_stack : ArrayRef
+  +egid : Int
+  +euid : Int
+  +gid : Int
+  +pid : Int
+  +propagated_stack : ArrayRef
+  +tid : Int
+  +time : Int
+  +uid : Int
+  ..
+  #defaults : HashRef
+  #default_attribute : Str = "message"
+  #numeric_attribute : Str = "value"
+  #eval_attribute : Str = "message"
+  #string_attributes : ArrayRef[Str] = ["message"]
+  ==
+  +new( args : Hash ) <<create>>
+  +throw( args : Hash = undef ) <<create>>
+  +throw( message : Str, args : Hash = undef ) <<create>>
+  ..
+  +catch() : Exception::Base
+  +catch( variable : Any ) : Exception::Base
+  +matches( that : Any ) : Bool {overload="~~"}
+  +to_string() : Str {overload='""'}
+  +to_number() : Num {overload="0+"}
+  +to_bool() : Bool {overload="bool"}
+  +get_caller_stacktrace() : Array[Str]|Str
+  +PROPAGATE()
+  ..
+  +ATTRS() : HashRef <<constant>>
+  ..
+  #_collect_system_data()
+  #_make_accessors() <<static>>
+  #_make_caller_info_accessors() <<static>>
+}
 
-[                           <<exception>>
-                           Exception::Base
- -----------------------------------------------------------------------------
- +ignore_class : ArrayRef                                                {new}
- +ignore_level : Int = 0                                                 {new}
- +ignore_package : ArrayRef                                              {new}
- +max_arg_len : Int = 64                                                 {new}
- +max_arg_nums : Int = 8                                                 {new}
- +max_eval_len : Int = 0                                                 {new}
- +message : Str|ArrayRef[Str] = "Unknown exception"                      {new}
- +value : Int = 0                                                        {new}
- +verbosity : Int = 2                                                    {new}
- +caller_stack : ArrayRef
- +egid : Int
- +euid : Int
- +gid : Int
- +pid : Int
- +propagated_stack : ArrayRef
- +tid : Int
- +time : Int
- +uid : Int
- #defaults : HashRef
- #default_attribute : Str = "message"
- #numeric_attribute : Str = "value"
- #eval_attribute : Str = "message"
- #string_attributes : ArrayRef[Str] = ["message"]
- -----------------------------------------------------------------------------
- <<create>> +new( args : Hash )
- <<create>> +throw( args : Hash = undef )
- <<create>> +throw( message : Str, args : Hash = undef )
- +catch() : Exception::Base
- +catch( variable : Any ) : Exception::Base
- +matches( that : Any ) : Bool                                 {overload="~~"}
- +to_string() : Str                                            {overload='""'}
- +to_number() : Num                                            {overload="0+"}
- +to_bool() : Bool                                           {overload="bool"}
- +get_caller_stacktrace() : Array[Str]|Str
- +PROPAGATE()
- #_collect_system_data()
- #_make_accessors()                                                     {init}
- #_make_caller_info_accessors()                                         {init}
- <<constant>> +ATTRS() : HashRef                                              ]
-
-=end umlwiki
+=end plantuml
 
 =head1 SEE ALSO
 
@@ -2358,7 +2352,7 @@ Piotr Roszatycki <dexter@cpan.org>
 
 =head1 LICENSE
 
-Copyright (c) 2007-2010, 2012-2013 Piotr Roszatycki <dexter@cpan.org>.
+Copyright (c) 2007-2015 Piotr Roszatycki <dexter@cpan.org>.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
